biom.load_table — biom-format.org

# biom-format.org

## biom.load_table

`biom.` `load_table`(f)

  Load a Table from a path

  Parameters: | f : str
  Returns: | Table
  Raises: | IOError If the path does not exist TypeError If the data in the path does not appear to be a BIOM table

  Examples

  Parse a table from a path. BIOM will attempt to determine if the fhe file is either in TSV, HDF5, JSON, gzip’d JSON or gzip’d TSV and parse accordingly:

      >>> from biom import load_table
      >>> table = load_table('path/to/table.biom')